% Construct example blind to Jaccard
clear all;
units=5; % must be able to divide by 5
clustsize=5;
X1=zeros(2*clustsize,5*units);
X1(1:clustsize,1:3*units)=1;
X1(clustsize+1:2*clustsize,2*units+1:4*units)=1;
X2=zeros(2,5*units);
X2(1:clustsize,(1+4/5)*units+1:(2+3/5)*units)=1;
X2(1:clustsize,4*units+1:(4+1/5)*units)=1;
X2(clustsize+1:2*clustsize,1:1*units)=1;
X2(clustsize+1:2*clustsize,(3+1/5)*units+1:(4+1/5)*units)=1;
% permute the data to reflect that the "true" clustering is unknown
X1=X1(randperm(size(X1,1)),:);
X2=X2(randperm(size(X2,1)),:);

% Plot the generated binary data
figure;
sf=14;
subplot(2,1,1)
colormap(1-gray)
imagesc(X1);
set(gca,'YDir','reverse')
title('System 1','Fontweight','bold','FontSize',sf)
ylabel('Object','Fontweight','bold','FontSize',sf)
xlabel('Feature','Fontweight','bold','FontSize',sf)
axis equal;
axis tight;

    
subplot(2,1,2)
colormap(1-gray)
imagesc(X2);
set(gca,'YDir','reverse')
title('System 2','Fontweight','bold','FontSize',sf)
ylabel('Object','Fontweight','bold','FontSize',sf)
xlabel('Feature','Fontweight','bold','FontSize',sf)
axis equal;
axis tight;


% Calculate matches
A=zeros(size(X1,1),size(X2,1),4);
A(:,:,1)=double(X1==0)*double(X2==0)';  % 0-0 matches
A(:,:,2)=double(X1==0)*double(X2==1)';  % 0-1 matches
A(:,:,3)=double(X1==1)*double(X2==0)';  % 1-0 matches
A(:,:,4)=double(X1==1)*double(X2==1)';  % 1-1 matches

% Plot the matches 
figure;
lab={'0-0 matches','0-1 matches','1-0 matches','1-1 matches'};
for c=1:4
    subplot(2,2,c)
    colormap(jet)
    imagesc(A(:,:,c));
    set(gca,'YDir','reverse')
    title([lab{c}],'Fontweight','bold','FontSize',sf);
    caxis([min(min(A(:,:,c))),max(max(A(:,:,c)))]);
    colorbar;    
    axis equal;
    axis tight;
    ylabel('System 1','FontSize',sf)
    xlabel('System 2','FontSize',sf)
end

% run algorithm
noc=[1 1];
opts.eta0=ones(1,size(A,3));
opts.maxiter=500;
opts.nsampleiter=250;
[L,cpu_time,Z,eta,sample]=IRMNwayMultinomial(A,noc,opts);
[~,Z1_sorted,Z2_sorted,eta_sorted,perm1,perm2]=sortGraphBipartite(A,sample.MAP.Z{1},sample.MAP.Z{2},sample.MAP.eta);
X1_sorted=X1(perm1,:);
X2_sorted=X2(perm2,:);
A_sorted=A(perm1,perm2,:);

% Plot the generated binary data
figure;
subplot(2,1,1)
colormap(1-gray)
imagesc(X1_sorted);
set(gca,'YDir','reverse')
title('Sorted System 1','Fontweight','bold','FontSize',sf)
ylabel('Object','Fontweight','bold','FontSize',sf)
xlabel('Feature','Fontweight','bold','FontSize',sf)
axis equal;
axis tight;

    
subplot(2,1,2)
colormap(1-gray)
imagesc(X2_sorted);
set(gca,'YDir','reverse')
title('Sorted System 2','Fontweight','bold','FontSize',sf)
ylabel('Object','Fontweight','bold','FontSize',sf)
xlabel('Feature','Fontweight','bold','FontSize',sf)
axis equal;
axis tight;

figure;
for c=1:4
    subplot(2,2,c);
    colormap(jet)
    imagesc(A_sorted(:,:,c));    
    addlines(A_sorted(:,:,c),flipud(Z1_sorted),Z2_sorted)    
    title(['sorted ' lab{c}],'Fontweight','bold','FontSize',sf);
    caxis([min(min(A_sorted(:,:,c))),max(max(A_sorted(:,:,c)))]);
    colorbar;    
    axis equal;
    axis tight;
    ylabel('System 1','FontSize',sf)
    xlabel('System 2','FontSize',sf)
end



